@@ -4,7 +4,7 @@
 ;; Base16: (https://github.com/tinted-theming/home)
 
 ;;; Authors:
-;; Scheme: Khue Nguyen &lt;Z5483Y@gmail.com&gt;
+;; Scheme: Tinted Theming (https://github.com/tinted-theming), Ayu Theme (https://github.com/ayu-theme)
 ;; Template: Kaleb Elwert <belak@coded.io>
 
 ;;; Code:
@@ -12,22 +12,22 @@
 (require 'base16-theme)
 
 (defvar base16-ayu-dark-theme-colors
-  '(:base00 "#0f1419"
+  '(:base00 "#0b0e14"
     :base01 "#131721"
-    :base02 "#272d38"
+    :base02 "#202229"
     :base03 "#3e4b59"
     :base04 "#bfbdb6"
     :base05 "#e6e1cf"
-    :base06 "#e6e1cf"
-    :base07 "#f3f4f5"
+    :base06 "#ece8db"
+    :base07 "#f2f0e7"
     :base08 "#f07178"
     :base09 "#ff8f40"
     :base0A "#ffb454"
-    :base0B "#b8cc52"
+    :base0B "#aad94c"
     :base0C "#95e6cb"
     :base0D "#59c2ff"
     :base0E "#d2a6ff"
-    :base0F "#e6b673")
+    :base0F "#e6b450")
   "All colors for Base16 Ayu Dark are defined here.")
 
 ;; Define the theme
