@@ -12,22 +12,22 @@
 (require 'base16-theme)
 
 (defvar base16-charcoal-light-theme-colors
-  '(:base00 "#d6b891"
-    :base01 "#c0a179"
-    :base02 "#a28662"
-    :base03 "#887254"
-    :base04 "#1e1812"
-    :base05 "#35291d"
-    :base06 "#413325"
-    :base07 "#d6b891"
-    :base08 "#413325"
-    :base09 "#120f09"
-    :base0A "#292016"
-    :base0B "#120f09"
-    :base0C "#413325"
-    :base0D "#120f09"
-    :base0E "#292016"
-    :base0F "#66553f")
+  '(:base00 "#cabda0"
+    :base01 "#bcad8c"
+    :base02 "#af9f7d"
+    :base03 "#645538"
+    :base04 "#110e06"
+    :base05 "#382e1b"
+    :base06 "#4b3e26"
+    :base07 "#bcad8c"
+    :base08 "#382e1b"
+    :base09 "#110e06"
+    :base0A "#110e06"
+    :base0B "#110e06"
+    :base0C "#110e06"
+    :base0D "#251e0f"
+    :base0E "#382e1b"
+    :base0F "#4b3e26")
   "All colors for Base16 Charcoal Light are defined here.")
 
 ;; Define the theme
