@@ -18,8 +18,8 @@
     :base03 "#ccd7da"
     :base04 "#8796b0"
     :base05 "#80cbc4"
-    :base06 "#80cbc4"
-    :base07 "#ffffff"
+    :base06 "#43a39a"
+    :base07 "#000000"
     :base08 "#ff5370"
     :base09 "#f76d47"
     :base0A "#ffb62c"
